/*
  Theremin
  Fényérzékelés fotoellenállás (LDR) segítségével, amelyet egy 
  feszültségosztó felső tagjának kötónk be.
  
          LDR      10k
    VCC--/\/\/\-+-/\/\/\--- GND 
                |
                A3
               
    Az ADC által mért - a megvilágítástól függő - értékből
    származtatott frekvenciát megszólaltatjuk, így a hangmagasság
    a fényérzékeny ellenállás megvilágításával vagy beárnyékolásával hangolható. 

    A program elején egy 5 másorperces intervallumban kalibráljuk a szenzort,
    eközben mozgassuk a kezünket a szenzor előtt, a kívánt tartományban.               
 */
#define buzzerPin 12                // Piezo buzzer D12 és a GND közé kötve
#define ledPin 13                   // A beépített LED
int ldr;                            // A beolvasott fényerősség érték (0-1023)
int ldrMin = 1023;                  // A fényerősség minimuma
int ldrMax = 0;                     // A fényerősség maximuma

void setup() {
  pinMode(ledPin, OUTPUT);          // ledPin legyen kimenet
  digitalWrite(ledPin, HIGH);       // LED be, kalibráció kezdete
  while (millis() < 5000) {         // 5 másodpercing kalibrálunk
    ldr = analogRead(A3);           // Fényszenzor leolvasása
    if (ldr > ldrMax) ldrMax = ldr; // A maximális érték eltárolása
    if (ldr < ldrMin) ldrMin = ldr; // A minimális érték eltárolása
  }
  digitalWrite(ledPin, LOW);        // LED ki, kalibráció vége
}

void loop() {
  ldr = analogRead(A3);             // Fényszenzor leolvasása
  //--- A fényerősség érték leképezése -----
  int freq = map(ldr,ldrMin,ldrMax,50,4000);
  tone(buzzerPin,freq,20);          // Megszólaltatjuk a hangot
  delay(10);                        // Egy kicsit várunk
}
